/v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »

# /v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload

Contents

- /v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload
  - POST /v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload
    - Parameters
    - Response status codes
    - Sample session

## POST /v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload

Reload a VirtualBox VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance reloaded

### Sample session

    curl -i -X POST 'http://localhost:8000/projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4c9fdef4-8990-44a1-8a98-1b7c510821ee/reload' -d '{}'

    POST /projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4c9fdef4-8990-44a1-8a98-1b7c510821ee/reload HTTP/1.1
    {}

    HTTP/1.1 204
    CONNECTION: keep-alive
    CONTENT-LENGTH: 0
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/virtualbox/vms/{vm_id}/reload

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »